@@ -1,5 +1,5 @@
-import objc
 import Cocoa
+import objc
 
 gNumDaysInMonth = (0, 31, 28, 31, 30, 21, 30, 31, 31, 30, 31, 30, 31)
 
@@ -35,7 +35,7 @@ class CalendarMatrix(Cocoa.NSMatrix):
                     val.setTag_(count)
                 count += 1
 
-        self._selectedDay = Cocoa.NSCalendarDate.dateWithYear_month_day_hour_minute_second_timeZone_(
+        self._selectedDay = Cocoa.NSCalendarDate.dateWithYear_month_day_hour_minute_second_timeZone_(  # noqa: B950
             now.yearOfCommonEra(),
             now.monthOfYear(),
             now.dayOfMonth(),
@@ -51,14 +51,16 @@ class CalendarMatrix(Cocoa.NSMatrix):
         prevSelDate = self.selectedDay()
         selDay = self.selectedCell().tag() - self._startOffset + 1
 
-        selDate = Cocoa.NSCalendarDate.dateWithYear_month_day_hour_minute_second_timeZone_(
-            prevSelDate.yearOfCommonEra(),
-            prevSelDate.monthOfYear(),
-            selDay,
-            0,
-            0,
-            0,
-            Cocoa.NSTimeZone.localTimeZone(),
+        selDate = (
+            Cocoa.NSCalendarDate.dateWithYear_month_day_hour_minute_second_timeZone_(
+                prevSelDate.yearOfCommonEra(),
+                prevSelDate.monthOfYear(),
+                selDay,
+                0,
+                0,
+                0,
+                Cocoa.NSTimeZone.localTimeZone(),
+            )
         )
         self.setSelectedDay_(selDate)
         self.highlightTodayIfVisible()
@@ -105,8 +107,10 @@ class CalendarMatrix(Cocoa.NSMatrix):
         currentMonth = selDate.monthOfYear()
         currentYear = selDate.yearOfCommonEra()
 
-        firstOfMonth = Cocoa.NSCalendarDate.dateWithYear_month_day_hour_minute_second_timeZone_(
-            currentYear, currentMonth, 1, 0, 0, 0, Cocoa.NSTimeZone.localTimeZone()
+        firstOfMonth = (
+            Cocoa.NSCalendarDate.dateWithYear_month_day_hour_minute_second_timeZone_(
+                currentYear, currentMonth, 1, 0, 0, 0, Cocoa.NSTimeZone.localTimeZone()
+            )
         )
         self.monthName.setStringValue_(
             firstOfMonth.descriptionWithCalendarFormat_("%B %Y")
