@@ -1,21 +1,32 @@
 /*
- * Several methods of NSBezierPath cannot be handled automaticly because the
+ * Several methods of NSBezierPath cannot be handled automatically because the
  * size of a C-style array depends on the value of another argument.
  */
 
+#if PyObjC_BUILD_RELEASE < 1014
+#define NSBezierPathElementMoveTo NSMoveToBezierPathElement
+#define NSBezierPathElementLineTo NSLineToBezierPathElement
+#define NSBezierPathElementCurveTo NSCurveToBezierPathElement
+#define NSBezierPathElementClosePath NSClosePathBezierPathElement
+#endif
+
 static PyObject*
 call_NSBezierPath_elementAtIndex_associatedPoints_(PyObject* method, PyObject* self,
-                                                   PyObject* arguments)
+                                                   PyObject* const* arguments,
+                                                   size_t           nargs)
 {
-    PyObject* result;
-    PyObject* v;
-    struct objc_super super;
-    NSInteger idx;
-    int pointCount;
-    NSPoint points[3];
+    PyObject*           result;
+    PyObject*           v;
+    struct objc_super   super;
+    NSInteger           idx;
+    int                 pointCount;
+    NSPoint             points[3];
     NSBezierPathElement res;
 
-    if (!PyArg_ParseTuple(arguments, Py_ARG_NSInteger, &idx)) {
+    if (PyObjC_CheckArgCount(method, 1, 1, nargs) == -1) {
+        return NULL;
+    }
+    if (PyObjC_PythonToObjC(@encode(NSInteger), arguments[0], &idx) == -1) {
         return NULL;
     }
 
@@ -44,16 +55,16 @@ call_NSBezierPath_elementAtIndex_associatedPoints_(PyObject* method, PyObject* s
     }
 
     switch (res) {
-    case NSMoveToBezierPathElement:
+    case NSBezierPathElementMoveTo:
         pointCount = 1;
         break;
-    case NSLineToBezierPathElement:
+    case NSBezierPathElementLineTo:
         pointCount = 1;
         break;
-    case NSCurveToBezierPathElement:
+    case NSBezierPathElementCurveTo:
         pointCount = 3;
         break;
-    case NSClosePathBezierPathElement:
+    case NSBezierPathElementClosePath:
         pointCount = 0;
         break;
     default:
@@ -85,17 +96,21 @@ call_NSBezierPath_elementAtIndex_associatedPoints_(PyObject* method, PyObject* s
 
 static PyObject*
 call_NSBezierPath_setAssociatedPoints_atIndex_(PyObject* method, PyObject* self,
-                                               PyObject* arguments)
+                                               PyObject* const* arguments, size_t nargs)
 {
-    PyObject* result;
+    PyObject*         result;
     struct objc_super super;
-    NSInteger idx;
-    NSPoint points[3];
-    PyObject* pointList;
-    PyObject* seq;
-    int i, len;
+    NSInteger         idx;
+    NSPoint           points[3];
+    PyObject*         pointList;
+    PyObject*         seq;
+    int               i, len;
 
-    if (!PyArg_ParseTuple(arguments, "O" Py_ARG_NSInteger, &pointList, &idx)) {
+    if (PyObjC_CheckArgCount(method, 2, 2, nargs) == -1) {
+        return NULL;
+    }
+    pointList = arguments[0];
+    if (PyObjC_PythonToObjC(@encode(NSInteger), arguments[1], &idx) == -1) {
         return NULL;
     }
 
@@ -157,18 +172,18 @@ imp_NSBezierPath_elementAtIndex_associatedPoints_(void* cif __attribute__((__unu
 {
     id self = *(id*)args[0];
     // SEL _meth = *(SEL*)args[1];
-    NSInteger idx = *(NSInteger*)args[2];
-    NSPoint* points = *(NSPoint**)args[3];
+    NSInteger idx    = *(NSInteger*)args[2];
+    NSPoint*  points = *(NSPoint**)args[3];
 
     PyObject* result;
-    PyObject* seq = NULL;
+    PyObject* seq     = NULL;
     PyObject* arglist = NULL;
     PyObject* v;
-    int err;
-    int pointCount;
-    int i;
+    int       err;
+    int       pointCount;
+    int       i;
     PyObject* pyself = NULL;
-    int cookie = 0;
+    int       cookie = 0;
 
     PyGILState_STATE state = PyGILState_Ensure();
 
@@ -195,13 +210,13 @@ imp_NSBezierPath_elementAtIndex_associatedPoints_(void* cif __attribute__((__unu
     if (result == NULL)
         goto error;
 
-    seq = PySequence_Fast(result, "should return tuple of lenght 2");
+    seq = PySequence_Fast(result, "should return tuple of length 2");
     Py_DECREF(result);
     if (seq == NULL)
         goto error;
 
     if (PySequence_Fast_GET_SIZE(seq) != 2) {
-        PyErr_SetString(PyExc_ValueError, "should return tuple of lenght 2");
+        PyErr_SetString(PyExc_ValueError, "should return tuple of length 2");
         goto error;
     }
 
@@ -217,16 +232,16 @@ imp_NSBezierPath_elementAtIndex_associatedPoints_(void* cif __attribute__((__unu
         goto error;
 
     switch (*(NSBezierPathElement*)resp) {
-    case NSMoveToBezierPathElement:
+    case NSBezierPathElementMoveTo:
         pointCount = 1;
         break;
-    case NSLineToBezierPathElement:
+    case NSBezierPathElementLineTo:
         pointCount = 1;
         break;
-    case NSCurveToBezierPathElement:
+    case NSBezierPathElementCurveTo:
         pointCount = 3;
         break;
-    case NSClosePathBezierPathElement:
+    case NSBezierPathElementClosePath:
         pointCount = 0;
         break;
     default:
@@ -275,15 +290,16 @@ setup_nsbezierpath(PyObject* m __attribute__((__unused__)))
 
     if (PyObjC_RegisterMethodMapping(cls, @selector(elementAtIndex:associatedPoints:),
                                      call_NSBezierPath_elementAtIndex_associatedPoints_,
-                                     imp_NSBezierPath_elementAtIndex_associatedPoints_) <
-        0) {
+                                     imp_NSBezierPath_elementAtIndex_associatedPoints_)
+        < 0) {
 
         return -1;
     }
 
     if (PyObjC_RegisterMethodMapping(cls, @selector(setAssociatedPoints:atIndex:),
                                      call_NSBezierPath_setAssociatedPoints_atIndex_,
-                                     PyObjCUnsupportedMethod_IMP) < 0) {
+                                     PyObjCUnsupportedMethod_IMP)
+        < 0) {
 
         return -1;
     }
