@@ -1,5 +1,6 @@
-from PyObjCTools.TestSupport import *
 import AppKit
+from PyObjCTools.TestSupport import TestCase, min_sdk_level
+import objc
 
 
 class TestNSAccessibilityCustomRotor(TestCase):
@@ -28,11 +29,8 @@ class TestNSAccessibilityCustomRotor(TestCase):
         self.assertEqual(AppKit.NSAccessibilityCustomRotorTypeTextField, 18)
         self.assertEqual(AppKit.NSAccessibilityCustomRotorTypeUnderlinedText, 19)
         self.assertEqual(AppKit.NSAccessibilityCustomRotorTypeVisitedLink, 20)
+        self.assertEqual(AppKit.NSAccessibilityCustomRotorTypeAudiograph, 21)
 
     @min_sdk_level("10.13")
     def testProtocols(self):
         objc.protocolNamed("NSAccessibilityCustomRotorItemSearchDelegate")
-
-
-if __name__ == "__main__":
-    main()
