@@ -412,10 +412,14 @@ class TestNSURLSession(TestCase):
             Foundation.NSURLSessionTaskTransactionMetrics.isMultipath
         )
 
-    @min_os_level("10.16")
-    def testMethods10_16(self):
-        self.assertResultIsBOOL(Foundation.NSURLSessionConfiguration.sessionSendsLaunchEvents)
-        self.assertArgIsBOOL(Foundation.NSURLSessionConfiguration.setSessionSendsLaunchEvents_, 0)
+    @min_os_level("11.0")
+    def testMethods11_0(self):
+        self.assertResultIsBOOL(
+            Foundation.NSURLSessionConfiguration.sessionSendsLaunchEvents
+        )
+        self.assertArgIsBOOL(
+            Foundation.NSURLSessionConfiguration.setSessionSendsLaunchEvents_, 0
+        )
 
     @min_sdk_level("10.12")
     def testProtocols10_12(self):
